emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

master 3bab147 3/3: Rename "Homepage" field to "Website" in package desc


From: Stefan Kangas
Subject: master 3bab147 3/3: Rename "Homepage" field to "Website" in package description
Date: Sun, 26 Sep 2021 08:55:36 -0400 (EDT)

branch: master
commit 3bab1476f63075671b6c40c4ad13d758a0064caa
Author: Stefan Kangas <stefan@marxist.se>
Commit: Stefan Kangas <stefan@marxist.se>

    Rename "Homepage" field to "Website" in package description
    
    * lisp/emacs-lisp/package.el (describe-package-1): Rename
    "Homepage" field to "Website".
    
    * test/lisp/emacs-lisp/package-tests.el
    (package-test-describe-package)
    (package-test-describe-installed-multi-file-package)
    (package-test-describe-non-installed-package)
    (package-test-describe-non-installed-multi-file-package): Update tests.
---
 lisp/emacs-lisp/package.el            | 24 ++++++++++++------------
 test/lisp/emacs-lisp/package-tests.el |  8 ++++----
 2 files changed, 16 insertions(+), 16 deletions(-)

diff --git a/test/lisp/emacs-lisp/package-tests.el 
b/test/lisp/emacs-lisp/package-tests.el
index 2943579..77bc811 100644
--- a/test/lisp/emacs-lisp/package-tests.el
+++ b/test/lisp/emacs-lisp/package-tests.el
@@ -636,7 +636,7 @@ but with a different end of line convention (bug#48137)."
      (save-excursion (should (re-search-forward "Status: Installed in 
['`‘]simple-single-1.3/['’] (unsigned)." nil t)))
      (save-excursion (should (search-forward "Version: 1.3" nil t)))
      (save-excursion (should (search-forward "Summary: A single-file package 
with no dependencies" nil t)))
-     (save-excursion (should (search-forward "Homepage: http://doodles.au"; nil 
t)))
+     (save-excursion (should (search-forward "Website: http://doodles.au"; nil 
t)))
      (save-excursion (should (re-search-forward "Keywords: \\[?frobnicate\\]?" 
nil t)))
      (save-excursion (should (search-forward "This package provides a minor 
mode to frobnicate"
                                              nil t)))
@@ -652,7 +652,7 @@ but with a different end of line convention (bug#48137)."
     (with-fake-help-buffer
      (describe-package 'multi-file)
      (goto-char (point-min))
-     (should (search-forward "Homepage: http://puddles.li"; nil t))
+     (should (search-forward "Website: http://puddles.li"; nil t))
      (should (search-forward "This is a bare-bones readme file for the 
multi-file"
                              nil t)))))
 
@@ -665,7 +665,7 @@ but with a different end of line convention (bug#48137)."
     (with-fake-help-buffer
      (describe-package 'simple-single)
      (goto-char (point-min))
-     (should (search-forward "Homepage: http://doodles.au"; nil t))
+     (should (search-forward "Website: http://doodles.au"; nil t))
      (should (search-forward "This package provides a minor mode to frobnicate"
                              nil t)))))
 
@@ -678,7 +678,7 @@ but with a different end of line convention (bug#48137)."
     (with-fake-help-buffer
      (describe-package 'multi-file)
      (goto-char (point-min))
-     (should (search-forward "Homepage: http://puddles.li"; nil t))
+     (should (search-forward "Website: http://puddles.li"; nil t))
      (should (search-forward "This is a bare-bones readme file for the 
multi-file"
                              nil t)))))
 



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/lisp/emacs-lisp/package.el b/lisp/emacs-lisp/package.el
index 94087d1..62f5fc7 100644
--- a/lisp/emacs-lisp/package.el
+++ b/lisp/emacs-lisp/package.el
@@ -1118,7 +1118,7 @@ is wrapped around any parts requiring it."
 
 (declare-function lm-header "lisp-mnt" (header))
 (declare-function lm-header-multiline "lisp-mnt" (header))
-(declare-function lm-homepage "lisp-mnt" (&optional file))
+(declare-function lm-website "lisp-mnt" (&optional file))
 (declare-function lm-keywords-list "lisp-mnt" (&optional file))
 (declare-function lm-maintainers "lisp-mnt" (&optional file))
 (declare-function lm-authors "lisp-mnt" (&optional file))
@@ -1153,7 +1153,7 @@ boundaries."
             (or (lm-header "package-version") (lm-header "version")))
            (pkg-version (package-strip-rcs-id version-info))
            (keywords (lm-keywords-list))
-           (homepage (lm-homepage)))
+           (website (lm-website)))
       (unless pkg-version
          (if version-info
              (error "Unrecognized package version: %s" version-info)
@@ -1164,7 +1164,7 @@ boundaries."
          (package--prepare-dependencies
           (package-read-from-string (mapconcat #'identity require-lines " "))))
        :kind 'single
-       :url homepage
+       :url website
        :keywords keywords
        :maintainer
        ;; For backward compatibility, use a single string if there's only
@@ -2170,7 +2170,7 @@ Otherwise return nil."
       ;; to make sure we use a "canonical name"!
       (if l (package-version-join l)))))
 
-(declare-function lm-homepage "lisp-mnt" (&optional file))
+(declare-function lm-website "lisp-mnt" (&optional file))
 
 ;;;###autoload
 (defun package-install-from-buffer ()
@@ -2506,7 +2506,7 @@ Helper function for `describe-package'."
          (version (if desc (package-desc-version desc)))
          (archive (if desc (package-desc-archive desc)))
          (extras (and desc (package-desc-extras desc)))
-         (homepage (cdr (assoc :url extras)))
+         (website (cdr (assoc :url extras)))
          (commit (cdr (assoc :commit extras)))
          (keywords (if desc (package-desc--keywords desc)))
          (built-in (eq pkg-dir 'builtin))
@@ -2619,20 +2619,20 @@ Helper function for `describe-package'."
             (help-insert-xref-button text 'help-package
                                      (package-desc-name pkg))))
         (insert "\n")))
-    (when homepage
-      ;; Prefer https for the homepage of packages on common domains.
+    (when website
+      ;; Prefer https for the website of packages on common domains.
       (when (string-match-p (rx bol "http://"; (or "elpa." "www." "git." "")
                                 (or "nongnu.org" "gnu.org" "sr.ht"
                                     "emacswiki.org" "gitlab.com" "github.com")
                                 "/")
-                            homepage)
+                            website)
         ;; But only if the user has "https" in `package-archives'.
         (let ((gnu (cdr (assoc "gnu" package-archives))))
           (and gnu (string-match-p "^https" gnu)
-               (setq homepage
-                     (replace-regexp-in-string "^http" "https" homepage)))))
-      (package--print-help-section "Homepage")
-      (help-insert-xref-button homepage 'help-url homepage)
+               (setq website
+                     (replace-regexp-in-string "^http" "https" website)))))
+      (package--print-help-section "Website")
+      (help-insert-xref-button website 'help-url website)
       (insert "\n"))
     (when keywords
       (package--print-help-section "Keywords")